import random
import requests
from bs4 import BeautifulSoup
from base64 import b64encode
from sys import stdout


def get_jbzd_random_url():
    r = requests.get('https://jbzd.com.pl')
    soup = BeautifulSoup(r.text, 'html.parser')
    urls = soup.findAll("img", class_="article-image")
    draw_url = urls[random.randint(0, len(urls) - 1)].attrs['src']
    return draw_url


def get_image_content(url):
    return requests.get(url).content


def print_image(data):
    image_b64_data = b64encode(data)
    image_size = str(len(image_b64_data))
    header = bytes('\033]1337;File=;size={};inline=1:'.format(image_size).encode('utf-8'))
    stdout.buffer.write(header + image_b64_data + b'\a\n')


def main():
    print_image(get_image_content(get_jbzd_random_url()))



from setuptools import setup
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='jbzd_imgcat',
    version='0.0.2',
    description='jbzd.com.pl imgcat',
    url='https://github.com/leszekbulawa/jbzd_imgcat',
    author='Leszek Buława',
    author_email='leszekbu@gmail.com',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3',
    ],
    keywords='jbzd jbzd.pl jbzd.com.pl imgcat',
    py_modules=['jbzd_imgcat'],
    install_requires=['requests', 'BeautifulSoup4'],
    entry_points={
        'console_scripts': [
            'jbzd_imgcat=jbzd_imgcat:main',
        ],
    },
)
